@@ -1,5 +1,5 @@
 """
-Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - January 19, 2022
+Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - January 25, 2022
 """
 
 import time
@@ -35,7 +35,7 @@ def openTEPES_run(DirName, CaseName, SolverName, pIndLogConsole):
     idxDict['y'  ] = 1
 
     #%% model declaration
-    mTEPES = ConcreteModel('Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - Version 4.3.1 - January 19, 2021')
+    mTEPES = ConcreteModel('Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - Version 4.3.3 - January 25, 2022')
 
     pIndLogConsole = [j for i, j in idxDict.items() if i == pIndLogConsole]
 
@@ -67,13 +67,14 @@ def openTEPES_run(DirName, CaseName, SolverName, pIndLogConsole):
         NetworkSwitchingModelFormulation   (mTEPES, mTEPES, pIndLogConsole, st)
         NetworkOperationModelFormulation   (mTEPES, mTEPES, pIndLogConsole, st)
 
-    StartTime         = time.time()
-    mTEPES.write(_path+'/openTEPES_'+CaseName+'.lp', io_options={'symbolic_solver_labels': True})  # create lp-format file
-    WritingLPFileTime = time.time() - StartTime
-    StartTime         = time.time()
-    print('Writing LP file                        ... ', round(WritingLPFileTime), 's')
+    if pIndLogConsole == 1:
+        StartTime         = time.time()
+        mTEPES.write(_path+'/openTEPES_'+CaseName+'.lp', io_options={'symbolic_solver_labels': True})  # create lp-format file
+        WritingLPFileTime = time.time() - StartTime
+        StartTime         = time.time()
+        print('Writing LP file                        ... ', round(WritingLPFileTime), 's')
 
-    ProblemSolving(DirName, CaseName, SolverName, mTEPES, mTEPES)
+    ProblemSolving(DirName, CaseName, SolverName, mTEPES, mTEPES, pIndLogConsole)
 
     mTEPES.del_component(mTEPES.sc)
     mTEPES.del_component(mTEPES.p )
